import Cookies from 'js-cookie'

const sidebarStatusCookiesKey = process.env.VUE_APP_PROJECT_KEY + '-sidebarStatus'
const sizeCookiesKey = process.env.VUE_APP_PROJECT_KEY + '-size'

const state = {
  sidebar: {
    opened: Cookies.get(sidebarStatusCookiesKey) ? !!+Cookies.get(sidebarStatusCookiesKey) : true,
    withoutAnimation: false
  },
  device: 'desktop',
  size: Cookies.get(sizeCookiesKey) || 'medium'
}

const mutations = {
  TOGGLE_SIDEBAR: state => {
    state.sidebar.opened = !state.sidebar.opened
    state.sidebar.withoutAnimation = false
    if (state.sidebar.opened) {
      Cookies.set(sidebarStatusCookiesKey, 1)
    } else {
      Cookies.set(sidebarStatusCookiesKey, 0)
    }
  },
  CLOSE_SIDEBAR: (state, withoutAnimation) => {
    Cookies.set(sidebarStatusCookiesKey, 0)
    state.sidebar.opened = false
    state.sidebar.withoutAnimation = withoutAnimation
  },
  TOGGLE_DEVICE: (state, device) => {
    state.device = device
  },
  SET_SIZE: (state, size) => {
    state.size = size
    Cookies.set(sizeCookiesKey, size)
  }
}

const actions = {
  toggleSideBar({ commit }) {
    commit('TOGGLE_SIDEBAR')
  },
  closeSideBar({ commit }, { withoutAnimation }) {
    commit('CLOSE_SIDEBAR', withoutAnimation)
  },
  toggleDevice({ commit }, device) {
    commit('TOGGLE_DEVICE', device)
  },
  setSize({ commit }, size) {
    commit('SET_SIZE', size)
  }
}

export default {
  namespaced: true,
  state,
  mutations,
  actions
}
